import { BuildContext } from '../query/buildContext';
import { Column, ColumnImplementation } from './columns';
import { Table } from './types';
/**
 * Base object for all tables implementing the TableProjectionMethods
 *
 * The implementation is hidden anyway thus we're free to use lots of any's.
 */
export declare class TableImplementation {
    tableName: string;
    tableQuery?: (ctx: BuildContext) => string;
    tableResultConverter?: (row: any) => void;
    tableColumns: {
        [key: string]: ColumnImplementation;
    };
    selected?: string[];
    renamed?: Record<string, string>;
    projection?: {
        type: 'jsonBuildObject';
        name: string;
    } | {
        type: 'jsonAgg';
        name: string;
        orderBy?: string;
        direction?: 'ASC' | 'DESC';
    };
    referencedColumn?: string;
    constructor(tableName: string, tableColumns: {
        [key: string]: ColumnImplementation;
    });
    debugInfo(): string;
    copy(): TableImplementation;
    createTableColumn(name: string): TableImplementation;
    getTableProxy(): Table<any, any, any>;
    getColumns(): string[];
    getColumnResultKey(columnKey: string): string;
    getSelectSql(alias: string | undefined): string;
    getTableSql(alias: string, ctx: BuildContext): string;
    getReferencedColumn(): ColumnImplementation;
    getReferencedColumnSql(alias: string): string;
    getPrimaryColumnsSql(alias: string): string[];
    needsGroupBy(): boolean;
    getResultConverter(): (row: any) => void;
    select(...keys: string[]): Table<any, any, any>;
    selectWithout(...keys: string[]): Table<any, any, any>;
    selectAs(mapping: Record<string, string>): Table<any, any, any>;
    selectAsJson(key: string): Table<any, any, any>;
    selectAsJsonAgg(key: any, orderBy?: any, direction?: 'ASC' | 'DESC'): any;
    column(name: string): TableImplementation;
}
/**
 * Define a relation consisting of typed columns.
 */
export declare function table<T, S extends T, P = {}>(tableName: string, columns: {
    [K in keyof T]: Column<T[K]>;
}): Table<T, S, P>;
export declare function getTableImplementation(table: any): TableImplementation;
